@@ -64,7 +64,7 @@ class ContextCupy(XContext):
     def __init__(self, default_block_size=256, device=None):
 
         if device is not None:
-            cupy.Device(device).use()
+            cupy.cuda.Device(device).use()
 
         super().__init__()
 
@@ -299,7 +299,7 @@ class BufferCupy(XBuffer):
 
     def to_nplike(self, offset, dtype, shape):
         """view in nplike"""
-        nbytes = np.prod(shape) * dtype.itemsize
+        nbytes = np.prod(shape) * np.dtype(dtype).itemsize
         return (
             self.buffer[offset : offset + nbytes]
             .view(dtype=dtype)
